aboutsummaryrefslogtreecommitdiff
path: root/src/addrman.h
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2022-03-28 11:41:20 +0200
committerMacroFake <falke.marco@gmail.com>2022-07-26 11:04:08 +0200
commitfa21fc60c292ab947b2200e54201440f16230566 (patch)
tree78560faca81169b481c1dc93ebe4787f32e40d15 /src/addrman.h
parentfa9284c3e9acec4b44b2560256f27b3d78c753e2 (diff)
downloadbitcoin-fa21fc60c292ab947b2200e54201440f16230566.tar.xz
scripted-diff: Rename addrman time symbols
-BEGIN VERIFY SCRIPT- ren() { sed -i "s:\<$1\>:$2:g" $(git grep -l "\<$1\>" ./src ./test); } ren nLastTry m_last_try ren nLastSuccess m_last_success ren nLastGood m_last_good ren nLastCountAttempt m_last_count_attempt ren nSinceLastTry since_last_try ren nTimePenalty time_penalty ren nUpdateInterval update_interval ren fCurrentlyOnline currently_online -END VERIFY SCRIPT-
Diffstat (limited to 'src/addrman.h')
-rw-r--r--src/addrman.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/addrman.h b/src/addrman.h
index a0063e8a9c..dd5a8afeb3 100644
--- a/src/addrman.h
+++ b/src/addrman.h
@@ -107,11 +107,11 @@ public:
*
* @param[in] vAddr Address records to attempt to add.
* @param[in] source The address of the node that sent us these addr records.
* @param[in] nTimePenalty A "time penalty" to apply to the address record's nTime. If a peer
* sends us an address record with nTime=n, then we'll add it to our
- * addrman with nTime=(n - nTimePenalty).
+ * addrman with nTime=(n - time_penalty).
* @return true if at least one address is successfully added. */
- bool Add(const std::vector<CAddress>& vAddr, const CNetAddr& source, int64_t nTimePenalty = 0);
+ bool Add(const std::vector<CAddress>& vAddr, const CNetAddr& source, int64_t time_penalty = 0);
/**
* Mark an address record as accessible and attempt to move it to addrman's tried table.
@@ -107,11 +107,11 @@ public:
* @param[in] vAddr Address records to attempt to add.
* @param[in] source The address of the node that sent us these addr records.
- * @param[in] nTimePenalty A "time penalty" to apply to the address record's nTime. If a peer
+ * @param[in] time_penalty A "time penalty" to apply to the address record's nTime. If a peer
* sends us an address record with nTime=n, then we'll add it to our